// $Id: quickfile-options.js,v 1.8 2004/11/03 16:30:19 Paul Tomlin Exp $

function onLoad ()
{
	// load the prefs
	this.prefs = qfGetPrefs();

	// set controls to reflect prefs
	document.getElementById('debug-enable').checked         = this.prefs.debug.enable;
	document.getElementById('debug-copynotmove').checked    = this.prefs.debug.copynotmove;
	document.getElementById('search-casesensitive').checked = this.prefs.search.casesensitive;
	document.getElementById('search-expandspaces').checked  = this.prefs.search.expandspaces;

	switch (prefs.search.root)
	{
		// all message folders
		case 'msgaccounts:/':
			document.getElementById('searchroot').selectedItem = document.getElementById('searchroot-all');
		break;

		// message folders on the server of the first selected message
		case 'msgaccount:/':
			document.getElementById('searchroot').selectedItem = document.getElementById('searchroot-messageroot');
		break;
		
		// user selected folder
		default:
			// There are two possibilities here
			//  1. The user selected a server to search from
			//  2. The user selected a folder to search from
			// 
			// In the case of (1) we determine this by searching the list of servers in the menupopup
			// If that fails, we assume (2)
			//
			// TODO: there has to be a better way to do this....
			
			for (var i = 0; i < document.getElementById('searchroot-servers').menupopup.childNodes.length; i++)
			{
				// is one of the servers the same as the selected search root
				if (document.getElementById('searchroot-servers').menupopup.childNodes.item(i).value == prefs.search.root)
				{
					// select the 'server' radiobutton
					document.getElementById('searchroot').selectedItem = document.getElementById('searchroot-server');
					
					// select the correct item in the menupopup
					document.getElementById('searchroot-servers').selectedIndex = i;
					
					// remember this URI
					this.userSearchRootURI = prefs.search.root;
				}
			}
		
			if (this.userSearchRootURI == undefined)
			{
				// select the 'this folder' radiobutton
				document.getElementById('searchroot').selectedItem = document.getElementById('searchroot-selected');

				// remember the users search root
				this.userSearchRootURI = prefs.search.root;

				// look up the nice name of the folder
				document.getElementById('searchroot-text').value = qfGetNameFromFolderURI(prefs.search.root);
			}
		break;
	}

	// default folder
	document.getElementById('defaultfolder-enable').checked = prefs.defaultfolder.enable;
	document.getElementById('defaultfolder-text').value = qfGetNameFromFolderURI(prefs.defaultfolder.folder);
	this.defaultFolderURI = prefs.defaultfolder.folder;

	// shortcut key & modifiers
	document.getElementById('shortcut-key').insertItemAt(0, prefs.shortcut.key.toUpperCase());
	document.getElementById('shortcut-key').selectedIndex = 0;
	
	if (prefs.shortcut.modifiers.indexOf('accel') > -1)
		document.getElementById('shortcut-modifier-accel').checked = true;

	if (prefs.shortcut.modifiers.indexOf('alt') > -1)
		document.getElementById('shortcut-modifier-alt').checked = true;

	if (prefs.shortcut.modifiers.indexOf('control') > -1)
		document.getElementById('shortcut-modifier-ctrl').checked = true;

	if (prefs.shortcut.modifiers.indexOf('meta') > -1)
		document.getElementById('shortcut-modifier-meta').checked = true;

	if (prefs.shortcut.modifiers.indexOf('shift') > -1)
		document.getElementById('shortcut-modifier-shift').checked = true;

	// create a new AutoCompleteSession for the search root
	var searchRootACS = new QuickFileACS();
	searchRootACS.searchRoot = 'msgaccounts:/';
	searchRootACS.onAutoCompleteCallbackObj = this;
	searchRootACS.onAutoCompleteCallbackFunc = onSearchRootCompleteLookup;
	
	if (searchRootACS.prepare())
		document.getElementById('searchroot-text').addSession(searchRootACS);
	else
		document.getElementById('searchroot-text').disabled = true;

	// create a new AutoCompleteSession for the default folder
	var defaultFolderACS = new QuickFileACS();
	defaultFolderACS.searchRoot = 'msgaccounts:/';
	defaultFolderACS.onAutoCompleteCallbackObj = this;
	defaultFolderACS.onAutoCompleteCallbackFunc = onDefaultFolderCompleteLookup;
	
	if (defaultFolderACS.prepare())
		document.getElementById('defaultfolder-text').addSession(defaultFolderACS);
	else
		document.getElementById('defaultfolder-text').disabled = true;
};

// called by the auto complete session when the user selects a valid
//  entry from the popup for the search root
function onSearchRootCompleteLookup (name, uri)
{
	this.userSearchRootURI = uri;
};

// called by the auto complete session when the user selects a valid
//  entry from the popup for the default folder
function onDefaultFolderCompleteLookup (name, uri)
{
	this.defaultFolderURI = uri;
};

function onOk ()
{
	// save the control values
	this.prefs.debug.enable         = document.getElementById('debug-enable').checked;
	this.prefs.debug.copynotmove    = document.getElementById('debug-copynotmove').checked;
	this.prefs.search.casesensitive = document.getElementById('search-casesensitive').checked;
	this.prefs.search.expandspaces  = document.getElementById('search-expandspaces').checked;

	// default folder
	if (document.getElementById('defaultfolder-enable').checked && this.defaultFolderURI)
	{
		prefs.defaultfolder.enable = true;
		prefs.defaultfolder.folder = this.defaultFolderURI;
	}
	else
	{
		prefs.defaultfolder.enable = false;
	}

	// search root
	if (document.getElementById('searchroot-all').selected)
	{
		this.prefs.search.root = 'msgaccounts:/'
	}
	else if (document.getElementById('searchroot-messageroot').selected)
	{
		this.prefs.search.root = 'msgaccount:/';
	}
	else if (document.getElementById('searchroot-server').selected)
	{
		this.prefs.search.root = document.getElementById('searchroot-servers').value;
	}
	else if (document.getElementById('searchroot-selected').selected)
	{
		this.prefs.search.root = this.userSearchRootURI;
	}
	else
	{
		this.prefs.search.root = 'msgaccounts:/'
	}

	// shortcut & modifiers
	prefs.shortcut.key = document.getElementById('shortcut-key').selectedItem.label;

	var modifiers = new Array();
	if (document.getElementById('shortcut-modifier-accel').checked)
		modifiers.push('accel');

	if (document.getElementById('shortcut-modifier-alt').checked)
		modifiers.push('alt');

	if (document.getElementById('shortcut-modifier-ctrl').checked)
		modifiers.push('control');

	if (document.getElementById('shortcut-modifier-meta').checked)
		modifiers.push('meta');

	if (document.getElementById('shortcut-modifier-shift').checked)
		modifiers.push('shift');
	
	prefs.shortcut.modifiers = modifiers.join(' ');
	
	qfSetPrefs(this.prefs);

	return true;
};

function onCancel ()
{
	return true;
};
